@@ -173,13 +173,13 @@ subroutine gener_pseudo
   do ns=1,nbeta
      nwf0=nstoae(ns)
      if (new(ns)) then
-        if(lpaw)then !AE scattering wfc normalized with rcutus
+!        if(lpaw)then !AE scattering wfc normalized with rcutus
            call set_psi_in(ikus(ns),lls(ns),jjs(ns),enls(ns),psipaw(1,ns),&
                                                         psipaw_rel(1,ns))
-        else
-           call set_psi_in(ik(ns),lls(ns),jjs(ns),enls(ns),psipaw(1,ns),&
-                                                        psipaw_rel(1,ns))
-        endif
+!        else
+!           call set_psi_in(ik(ns),lls(ns),jjs(ns),enls(ns),psipaw(1,ns),&
+!                                                        psipaw_rel(1,ns))
+!        endif
      else
         lam=lls(ns)
         nst=(lam+1)*2
@@ -394,7 +394,7 @@ subroutine gener_pseudo
            !
            bmat(ns,ns1)=bmat(ns,ns1)+enls(ns1)*qq(ns,ns1)
            !
-           !    Use symmetry of the n,ns1 indeces to set qvan and qq and bmat
+           !    Use symmetry of the n,ns1 indices to set qvan and qq and bmat
            !
            if (ns.ne.ns1) then
               do n=1,grid%mesh
