@@ -12,6 +12,7 @@ subroutine write_results
   use kinds,        only : dp
   use io_global, only : stdout, ionode_id, ionode
   use mp,        only : mp_bcast
+  use mp_world,  only : world_comm
   use constants, only : eps6
   use ld1inc,    only : title, rel, zed, lsd, nspin, isic, latt, beta, tr2, &
                         grid, enzero, etot, ekin, encl, ehrt, evxt, ecxc, &
@@ -50,7 +51,7 @@ subroutine write_results
 2300 format(5x,'dft =',a,'   lsd =',i1,' sic =',i1,' latt =',i1, &
        '  beta=',f4.2,' tr2=',1pe7.1)
   write(stdout,1270) grid%mesh,grid%r(grid%mesh),grid%xmin,grid%dx
-1270 format(5x,'mesh =',i4,' r(mesh) =',f10.5,' xmin =',f6.2,' dx =',f8.5)
+1270 format(5x,'mesh =',i4,' r(mesh) =',f10.5,' a.u. xmin =',f6.2,' dx =',f8.5)
   if (rel==0 .and. .not.relpert) then
      write(stdout,'(5x "1 Ry = ",f12.8, " eV" )') rytoev_fact
   else
@@ -432,7 +433,7 @@ subroutine write_results
   if (file_charge.ne.' ') then
      if (ionode) &
         open(unit=20,file=file_charge, status='unknown', iostat=ios, err=100 )
-100  call mp_bcast(ios, ionode_id)
+100  call mp_bcast(ios, ionode_id, world_comm)
      call errore('write_results','opening file'//file_charge,abs(ios))
      if (ionode) then
         IF (lsd<1) THEN
